ColorMisc class

Constructors

ColorMisc()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

nameToColor(String name) Color
withShade(Color color, num shadeFactor) Color
This class Applies values to colors and return either a darker shade or lighter tone of the same color shade_factor < 1.0
withTint(Color color, num tintFactor) Color
tint_factor < 1.0