ReactionProvider class
Properties
- db ↔ Database?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearCustomReactions(
) → Future< bool> -
clearHistory(
) → Future< bool> -
close(
) → Future< void> -
getCustomReaction(
{String? emoji, String? id}) → Future< Reaction?> -
getCustomReactions(
{int limit = 5}) → Future< List< Reaction> > -
getMostUsedReactions(
{int limit = 5}) → Future< List< Reaction> > -
getReaction(
String emoji) → Future< Reaction?> -
getRecentlyUsedReactions(
{int? limit}) → Future< List< Reaction> > -
insert(
Reaction reaction) → Future< Reaction?> -
insertCustomReactions(
Reaction reaction, {String? replace}) → Future< Reaction?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
open(
) → Future< void> -
openCustomReactions(
) → Future< void> -
removeCustomReaction(
String emoji) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
-
update(
Reaction reaction, {String table = tableName}) → Future< int>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance → ReactionProvider
-
final